/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Mozilla Reporter (r.m.o).
 *
 * The Initial Developer of the Original Code is
 *      Robert Accettura <robert@accettura.com>.
 *
 * Portions created by the Initial Developer are Copyright (C) 2004
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Gavin Sharp <gavin@gavinsharp.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */
 
var reporterListener = {

  QueryInterface: function(aIID) {
    if (aIID.equals(Components.interfaces.nsIWebProgressListener)   ||
        aIID.equals(Components.interfaces.nsISupportsWeakReference) ||
        aIID.equals(Components.interfaces.nsISupports))
      return this;
    throw Components.results.NS_NOINTERFACE;
  },

  onLocationChange: function(aProgress, aRequest, aURI) {
    var broadcaster = document.getElementById("reporterItemsBroadcaster");
    var isEnabled = false;

    if (aURI instanceof Components.interfaces.nsIURI) {
      switch (aURI.scheme) {
        case "http":
        case "https":
        case "ftp":
        case "gopher":
          isEnabled = true;
      }
    }

    broadcaster.setAttribute("disabled", !isEnabled);
  },

  onStateChange: function() {  },
  onProgressChange: function() {  },
  onStatusChange: function() {  },
  onSecurityChange: function() {  },
  onLinkIconAvailable: function() {  }
}

function onBrowserLoad() {
  gBrowser.addProgressListener(reporterListener);
}

function loadReporterWizard() {
  window.openDialog("chrome://reporter/content/reportWizard.xul", "",
                    "chrome,centerscreen,dialog,resizable=no,width=535,height=442",
                    getBrowser().currentURI.spec);
  return true;
}

window.addEventListener("load", onBrowserLoad, false);
